Ramsey One-Vertex Extension and Checking (ROVEaC)
=================================================

This is the repo for Ramsey theory utilities assisting in one-vertex extension and 
counterexample checking.

Read the documentaion here:

https://ramsey-ove-and-check.readthedocs.io/en/latest/

Find the code repository here:

https://github.com/aLehav/ramsey-ove-and-check/

This project is licensed under the Creative Commons Attribution-NonCommercial 4.0 International License. See the license file in the repository for details.
